@@ -1,8 +1,5 @@
-# This Source Code Form is subject to the terms of the Mozilla Public
-# License, v. 2.0. If a copy of the MPL was not distributed with this
-# file, You can obtain one at http://mozilla.org/MPL/2.0/.
-#
-# Copyright (C) 2017, James R. Barlow (https://github.com/jbarlow83/)
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: MPL-2.0
 
 """
 In several cases the implementation of some higher levels features might as
@@ -12,6 +9,8 @@ bindings after the fact.
 We can also move the implementation to C++ if desired.
 """
 
+from __future__ import annotations
+
 import datetime
 import mimetypes
 import shutil
@@ -21,18 +20,7 @@ from io import BytesIO
 from pathlib import Path
 from subprocess import run
 from tempfile import NamedTemporaryFile
-from typing import (
-    BinaryIO,
-    Callable,
-    ItemsView,
-    Iterator,
-    List,
-    Optional,
-    Tuple,
-    TypeVar,
-    Union,
-    ValuesView,
-)
+from typing import BinaryIO, Callable, ItemsView, Iterator, TypeVar, ValuesView
 from warnings import warn
 
 from . import Array, Dictionary, Name, Object, Page, Pdf, Stream
@@ -43,6 +31,7 @@ from ._qpdf import (
     AttachedFileSpec,
     Attachments,
     NameTree,
+    NumberTree,
     ObjectStreamMode,
     Rectangle,
     StreamDecodeLevel,
@@ -181,8 +170,8 @@ class Extend_Object:
         self,
         data: bytes,
         *,
-        filter: Union[Name, Array, None] = None,
-        decode_parms: Union[Dictionary, Array, None] = None,
+        filter: Name | Array | None = None,
+        decode_parms: Dictionary | Array | None = None,
         type_check: bool = True,
     ):  # pylint: disable=redefined-builtin
         """
@@ -384,7 +373,7 @@ class Extend_Pdf:
         return Stream(self, data, d, **kwargs)
 
     def add_blank_page(
-        self, *, page_size: Tuple[Numeric, Numeric] = (612.0, 792.0)
+        self, *, page_size: tuple[Numeric, Numeric] = (612.0, 792.0)
     ) -> Page:
         """
         Add a blank page to this PDF. If pages already exist, the page will be added to
@@ -468,7 +457,7 @@ class Extend_Pdf:
         """
         return EncryptionInfo(self._encryption_data)
 
-    def check(self) -> List[str]:
+    def check(self) -> list[str]:
         """
         Check if PDF is well-formed.  Similar to ``qpdf --check``.
         """
@@ -483,7 +472,7 @@ class Extend_Pdf:
             def handle_eof(self):
                 pass
 
-        problems: List[str] = []
+        problems: list[str] = []
 
         self._decode_all_streams_and_discard()
 
@@ -498,21 +487,21 @@ class Extend_Pdf:
 
     def save(
         self,
-        filename_or_stream: Union[Path, str, BinaryIO, None] = None,
+        filename_or_stream: Path | str | BinaryIO | None = None,
         *,
         static_id: bool = False,
         preserve_pdfa: bool = True,
-        min_version: Union[str, Tuple[str, int]] = "",
-        force_version: Union[str, Tuple[str, int]] = "",
+        min_version: str | tuple[str, int] = "",
+        force_version: str | tuple[str, int] = "",
         fix_metadata_version: bool = True,
         compress_streams: bool = True,
-        stream_decode_level: Optional[StreamDecodeLevel] = None,
+        stream_decode_level: StreamDecodeLevel | None = None,
         object_stream_mode: ObjectStreamMode = ObjectStreamMode.preserve,
         normalize_content: bool = False,
         linearize: bool = False,
         qdf: bool = False,
         progress: Callable[[int], None] = None,
-        encryption: Optional[Union[Encryption, bool]] = None,
+        encryption: Encryption | bool | None = None,
         recompress_flate: bool = False,
     ) -> None:
         """
@@ -668,9 +657,9 @@ class Extend_Pdf:
 
     @staticmethod
     def open(
-        filename_or_stream: Union[Path, str, BinaryIO],
+        filename_or_stream: Path | str | BinaryIO,
         *,
-        password: Union[str, bytes] = "",
+        password: str | bytes = "",
         hex_password: bool = False,
         ignore_xref_streams: bool = False,
         suppress_warnings: bool = True,
@@ -894,7 +883,7 @@ class Extend_Page:
         self,
         res: Object,
         res_type: Name,
-        name: Optional[Name] = None,
+        name: Name | None = None,
         *,
         prefix: str = '',
         replace_existing: bool = True,
@@ -960,7 +949,7 @@ class Extend_Page:
     def _over_underlay(
         self,
         other,
-        rect: Optional[Rectangle],
+        rect: Rectangle | None,
         under: bool,
         push_stack: bool,
         shrink: bool,
@@ -1001,8 +990,8 @@ class Extend_Page:
 
     def add_overlay(
         self,
-        other: Union[Object, Page],
-        rect: Optional[Rectangle] = None,
+        other: Object | Page,
+        rect: Rectangle | None = None,
         *,
         push_stack: bool = True,
         shrink: bool = True,
@@ -1059,8 +1048,8 @@ class Extend_Page:
 
     def add_underlay(
         self,
-        other: Union[Object, Page],
-        rect: Optional[Rectangle] = None,
+        other: Object | Page,
+        rect: Rectangle | None = None,
         *,
         shrink: bool = True,
         expand: bool = True,
@@ -1098,7 +1087,7 @@ class Extend_Page:
             other, rect, under=True, push_stack=False, expand=expand, shrink=shrink
         )
 
-    def contents_add(self, contents: Union[Stream, bytes], *, prepend: bool = False):
+    def contents_add(self, contents: Stream | bytes, *, prepend: bool = False):
         """Append or prepend to an existing page's content stream.
 
         Args:
@@ -1116,15 +1105,15 @@ class Extend_Page:
     def __setattr__(self, name, value):
         if hasattr(self.__class__, name):
             object.__setattr__(self, name, value)
-            return
-        setattr(self.obj, name, value)
+        else:
+            setattr(self.obj, name, value)
 
     @augment_override_cpp
     def __delattr__(self, name):
         if hasattr(self.__class__, name):
             object.__delattr__(self, name)
-            return
-        delattr(self.obj, name)
+        else:
+            delattr(self.obj, name)
 
     def __getitem__(self, key):
         return self.obj[key]
@@ -1138,9 +1127,6 @@ class Extend_Page:
     def __contains__(self, key):
         return key in self.obj
 
-    def __eq__(self, other):
-        return self.obj == other.obj
-
     def get(self, key, default=None):
         try:
             return self[key]
@@ -1219,7 +1205,7 @@ class Extend_Attachments(MutableMapping):
 @augments(AttachedFileSpec)
 class Extend_AttachedFileSpec:
     @staticmethod
-    def from_filepath(pdf: Pdf, path: Union[Path, str], *, description: str = ''):
+    def from_filepath(pdf: Pdf, path: Path | str, *, description: str = ''):
         """Construct a file specification from a file path.
 
         This function will automatically add a creation and modified date
@@ -1265,7 +1251,7 @@ class Extend_AttachedFileSpec:
 @augments(AttachedFile)
 class Extend_AttachedFile:
     @property
-    def creation_date(self) -> Optional[datetime.datetime]:
+    def creation_date(self) -> datetime.datetime | None:
         if not self._creation_date:
             return None
         return decode_pdf_date(self._creation_date)
@@ -1275,7 +1261,7 @@ class Extend_AttachedFile:
         self._creation_date = encode_pdf_date(value)
 
     @property
-    def mod_date(self) -> Optional[datetime.datetime]:
+    def mod_date(self) -> datetime.datetime | None:
         if not self._mod_date:
             return None
         return decode_pdf_date(self._mod_date)
@@ -1296,14 +1282,7 @@ class Extend_AttachedFile:
 
 
 @augments(NameTree)
-class Extend_NameTree(MutableMapping):
-    def __len__(self):
-        return len(self._as_map())
-
-    def __iter__(self):
-        for name, _value in self._nameval_iter():
-            yield name
-
+class Extend_NameTree:
     def keys(self):
         return KeysView(self._as_map())
 
@@ -1313,27 +1292,34 @@ class Extend_NameTree(MutableMapping):
     def items(self):
         return ItemsView(self._as_map())
 
-    def __eq__(self, other):
-        return self.obj.objgen == other.obj.objgen
+    get = MutableMapping.get
+    pop = MutableMapping.pop
+    popitem = MutableMapping.popitem
+    clear = MutableMapping.clear
+    update = MutableMapping.update
+    setdefault = MutableMapping.setdefault
 
-    def __contains__(self, name: Union[str, bytes]) -> bool:
-        """
-        Returns True if the name tree contains the specified name.
 
-        Args:
-            name (str or bytes): The name to search for in the name tree.
-                This is not a PDF /Name object, but an arbitrary key.
-                If name is a *str*, we search the name tree for the UTF-8
-                encoded form of name. If *bytes*, we search for a key
-                equal to those bytes.
-        """
-        return self._contains(name)
+MutableMapping.register(NameTree)
 
-    def __getitem__(self, name: Union[str, bytes]) -> Object:
-        return self._getitem(name)
 
-    def __setitem__(self, name: Union[str, bytes], o: Object):
-        self._setitem(name, o)
+@augments(NumberTree)
+class Extend_NumberTree:
+    def keys(self):
+        return KeysView(self._as_map())
 
-    def __delitem__(self, name: Union[str, bytes]):
-        self._delitem(name)
+    def values(self):
+        return ValuesView(self._as_map())
+
+    def items(self):
+        return ItemsView(self._as_map())
+
+    get = MutableMapping.get
+    pop = MutableMapping.pop
+    popitem = MutableMapping.popitem
+    clear = MutableMapping.clear
+    update = MutableMapping.update
+    setdefault = MutableMapping.setdefault
+
+
+MutableMapping.register(NumberTree)
