@@ -1,10 +1,5 @@
-/*
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- *
- * Copyright (C) 2017, James R. Barlow (https://github.com/jbarlow83/)
- */
+// SPDX-FileCopyrightText: 2022 James R. Barlow
+// SPDX-License-Identifier: MPL-2.0
 
 #include <cstring>
 #include <cctype>
@@ -160,16 +155,16 @@ bool objecthandle_equal(QPDFObjectHandle self, QPDFObjectHandle other)
 
         // Early out: if underlying QPDF Buffers happen to be the same, the data is the
         // same
-        if (self_buffer.getPointer() == other_buffer.getPointer())
+        if (self_buffer.get() == other_buffer.get())
             return true;
         // Early out: if sizes are different, data cannot be the same
-        if (self_buffer.getPointer()->getSize() != other_buffer.getPointer()->getSize())
+        if (self_buffer->getSize() != other_buffer->getSize())
             return false;
 
         // Slow path: memcmp the binary data
-        return 0 == std::memcmp(self_buffer.getPointer()->getBuffer(),
-                        other_buffer.getPointer()->getBuffer(),
-                        self_buffer.getPointer()->getSize());
+        return 0 == std::memcmp(self_buffer->getBuffer(),
+                        other_buffer->getBuffer(),
+                        self_buffer->getSize());
     }
     // LCOV_EXCL_START
     case QPDFObject::object_type_e::ot_boolean:
@@ -399,7 +394,7 @@ void init_object(py::module_ &m)
         .def(
             "__eq__",
             [](QPDFObjectHandle &self, QPDFObjectHandle &other) {
-                return (self == other); // overloaded
+                return objecthandle_equal(self, other);
             },
             py::is_operator())
         .def(
@@ -443,7 +438,7 @@ void init_object(py::module_ &m)
                     return py::reinterpret_borrow<py::object>(
                         py::handle(Py_NotImplemented));
                 }
-                bool result = (self == q_other);
+                bool result = objecthandle_equal(self, q_other);
                 return py::bool_(result);
             },
             py::is_operator())
@@ -482,15 +477,13 @@ void init_object(py::module_ &m)
             [](QPDFObjectHandle &h, std::string const &key, QPDFObjectHandle &value) {
                 object_set_key(h, key, value);
             },
-            "assign dictionary key to new object",
-            py::keep_alive<1, 3>())
+            "assign dictionary key to new object")
         .def(
             "__setitem__",
             [](QPDFObjectHandle &h, QPDFObjectHandle &name, QPDFObjectHandle &value) {
                 object_set_key(h, name.getName(), value);
             },
-            "assign dictionary key to new object",
-            py::keep_alive<1, 3>())
+            "assign dictionary key to new object")
         .def("__setitem__",
             [](QPDFObjectHandle &h, std::string const &key, py::object pyvalue) {
                 auto value = objecthandle_encode(pyvalue);
@@ -520,12 +513,12 @@ void init_object(py::module_ &m)
                     value = object_get_key(h, key);
                 } catch (const py::key_error &e) {
                     if (std::isupper(name[0]))
-                        throw py::attr_error(e.what());
+                        throw py::attribute_error(e.what());
                     else
-                        throw py::attr_error(name);
+                        throw py::attribute_error(name);
                 } catch (const py::value_error &e) {
                     if (name == std::string("__name__"))
-                        throw py::attr_error(name);
+                        throw py::attribute_error(name);
                     throw;
                 }
                 return value;
@@ -805,7 +798,6 @@ void init_object(py::module_ &m)
             since it does not take too long for modern CPUs to reconstruct an
             entire PDF. pikepdf will consolidate all incremental updates
             when saving.
-
             )~~~")
         .def_static(
             "parse",
@@ -954,9 +946,7 @@ void init_object(py::module_ &m)
             return QPDFObjectHandle::newStream(owner.get(),
                 data); // This makes a copy of the data
         },
-        "Construct a PDF Stream object from binary data",
-        py::keep_alive<0, 1>() // returned object references the owner
-    );
+        "Construct a PDF Stream object from binary data");
     m.def(
         "_new_operator",
         [](const std::string &op) { return QPDFObjectHandle::newOperator(op); },
@@ -1004,12 +994,14 @@ void init_object(py::module_ &m)
 
             Used to expose additional functionality specific to that object type.
         )~~~")
-        .def("__eq__",
+        .def(
+            "__eq__",
             [](QPDFObjectHelper &self, QPDFObjectHelper &other) {
                 // Pages that are copies
                 return objecthandle_equal(
                     self.getObjectHandle(), other.getObjectHandle());
-            })
+            },
+            py::is_operator())
         .def_property_readonly(
             "obj",
             [](QPDFObjectHelper &poh) -> QPDFObjectHandle {
