@@ -1,10 +1,5 @@
-/*
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- *
- * Copyright (C) 2017, James R. Barlow (https://github.com/jbarlow83/)
- */
+// SPDX-FileCopyrightText: 2022 James R. Barlow
+// SPDX-License-Identifier: MPL-2.0
 
 #include <sstream>
 #include <iostream>
@@ -92,7 +87,7 @@ void init_page(py::module_ &m)
                 the rotation rotates clockwise by ``90`` degrees.
             )~~~")
         .def("contents_coalesce",
-            &QPDFPageObjectHelper::coalesceContentStreams,
+            &QPDFPageObjectHelper::coalesceContentStreams, // LCOV_EXCL_LINE
             R"~~~(
                 Coalesce a page's content streams.
 
@@ -110,8 +105,7 @@ void init_page(py::module_ &m)
             },
             py::arg("contents"),
             py::kw_only(),
-            py::arg("prepend") = false,
-            py::keep_alive<1, 2>())
+            py::arg("prepend") = false)
         .def(
             "_contents_add",
             [](QPDFPageObjectHelper &poh, py::bytes contents, bool prepend) {
@@ -249,7 +243,6 @@ void init_page(py::module_ &m)
 
                 poh.addContentTokenFilter(tf);
             },
-            py::keep_alive<1, 2>(),
             py::arg("tf"),
             R"~~~(
                 Attach a :class:`pikepdf.TokenFilter` to a page's content stream.
