@@ -1,10 +1,5 @@
-/*
- * This Source Code Form is subject to the terms of the Mozilla Public
- * License, v. 2.0. If a copy of the MPL was not distributed with this
- * file, You can obtain one at http://mozilla.org/MPL/2.0/.
- *
- * Copyright (C) 2017, James R. Barlow (https://github.com/jbarlow83/)
- */
+// SPDX-FileCopyrightText: 2022 James R. Barlow
+// SPDX-License-Identifier: MPL-2.0
 
 #include <sstream>
 #include <type_traits>
@@ -644,9 +639,7 @@ void init_qpdf(py::module_ &m)
                 first (bool): If True, prepend this before the first page; if False append after last page
             )~~~",
             py::arg("page"),
-            py::arg("first") = false,
-            py::keep_alive<1, 2>())
-        .def("_add_page_at", &QPDF::addPageAt, py::keep_alive<1, 2>())
+            py::arg("first") = false)
         .def("_remove_page", &QPDF::removePage)
         .def(
             "remove_unreferenced_resources",
@@ -796,7 +789,6 @@ void init_qpdf(py::module_ &m)
                 Error messages improved.
             )~~~",
             py::return_value_policy::reference_internal,
-            py::keep_alive<1, 2>(),
             py::arg("h"))
         .def("copy_foreign",
             [](QPDF &q, QPDFPageObjectHelper &poh) -> QPDFPageObjectHelper {
