@@ -1,13 +1,17 @@
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: CC0-1.0
+
+from __future__ import annotations
+
 import json
 import sys
 from copy import copy
 from decimal import Decimal, InvalidOperation
 from math import isclose, isfinite
-from typing import Type
 from zlib import compress
 
 import pytest
-from conftest import needs_libqpdf_v, skip_if_pypy
+from conftest import skip_if_pypy
 from hypothesis import assume, example, given
 from hypothesis.strategies import (
     binary,
@@ -632,6 +636,17 @@ class TestStream:
         stream2.stream_dict.SomeData = 1
         assert stream2 != stream1
 
+    def test_stream_refcount(self, refcount, outpdf):
+        pdf = pikepdf.new()
+        stream = Stream(pdf, b'blahblah')
+        assert refcount(stream) == 2
+        pdf.Root.SomeStream = stream
+        assert refcount(stream) == 2
+        del stream
+        pdf.save(outpdf)
+        with pikepdf.open(outpdf) as pdf2:
+            assert pdf2.Root.SomeStream.read_bytes() == b'blahblah'
+
 
 @pytest.fixture
 def sandwich(resources):
