@@ -1,3 +1,8 @@
+# SPDX-FileCopyrightText: 2022 James R. Barlow
+# SPDX-License-Identifier: CC0-1.0
+
+from __future__ import annotations
+
 import copy
 from typing import List, Union
 
@@ -173,9 +178,9 @@ def test_fourpages_to_4up(fourpages, graph, outpdf):
     pdf.save(outpdf)
 
 
-def _simple_interpret_content_stream(page: Union[Page, Object]):
+def _simple_interpret_content_stream(page: Page | Object):
     ctm = PdfMatrix.identity()
-    stack: List[PdfMatrix] = []
+    stack: list[PdfMatrix] = []
     for instruction in parse_content_stream(page, operators='q Q cm Do'):
         if isinstance(instruction, ContentStreamInlineImage):
             continue
@@ -237,6 +242,8 @@ def test_page_equal(fourpages, graph):
     assert graph.pages[1] == graph.pages[0]
     assert copy.copy(graph.pages[1]) == graph.pages[0]
 
+    assert graph.pages[0] != "dissimilar type"
+
 
 def test_cant_hash_page(graph):
     with pytest.raises(TypeError, match="unhashable"):
